Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/phpmyadmin/phpmyadmin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMaurício Meneghini Fauth <mauriciofauth@gmail.com>2018-08-12 01:42:27 +0300
committerMaurício Meneghini Fauth <mauriciofauth@gmail.com>2018-11-11 01:48:58 +0300
commitc1cdaac2f465dd6b9e17f9f35fd46861ad703a6d (patch)
treef95cd3fd2fbc75ba38e6d9f9a4fa46cbed2559b6 /db_export.php
parent259cbc6ab1d61afb3a657ad4a787eefe8278ec29 (diff)
Retrieve parameters from $_POST in export
Signed-off-by: Maurício Meneghini Fauth <mauriciofauth@gmail.com>
Diffstat (limited to 'db_export.php')
-rw-r--r--db_export.php24
1 files changed, 12 insertions, 12 deletions
diff --git a/db_export.php b/db_export.php
index b04a8b0193..74010befbd 100644
--- a/db_export.php
+++ b/db_export.php
@@ -56,8 +56,8 @@ if ($num_tables < 1) {
} // end if
$multi_values = '<div class="export_table_list_container">';
-if (isset($_GET['structure_or_data_forced'])) {
- $force_val = htmlspecialchars($_GET['structure_or_data_forced']);
+if (isset($_POST['structure_or_data_forced'])) {
+ $force_val = htmlspecialchars($_POST['structure_or_data_forced']);
} else {
$force_val = 0;
}
@@ -84,19 +84,19 @@ if (!empty($_POST['selected_tbl']) && empty($table_select)) {
$table_select = $_POST['selected_tbl'];
}
// Check if the selected tables are defined in $_GET
// (from clicking Back button on export.php)
foreach (array('table_select', 'table_structure', 'table_data') as $one_key) {
- if (isset($_GET[$one_key])) {
- $_GET[$one_key] = urldecode($_GET[$one_key]);
- $_GET[$one_key] = explode(",", $_GET[$one_key]);
+ if (isset($_POST[$one_key])) {
+ $_POST[$one_key] = urldecode($_POST[$one_key]);
+ $_POST[$one_key] = explode(",", $_POST[$one_key]);
}
}
foreach ($tables as $each_table) {
- if (isset($_GET['table_select']) && is_array($_GET['table_select'])) {
+ if (isset($_POST['table_select']) && is_array($_POST['table_select'])) {
$is_checked = Export::getCheckedClause(
- $each_table['Name'], $_GET['table_select']
+ $each_table['Name'], $_POST['table_select']
);
} elseif (isset($table_select)) {
$is_checked = Export::getCheckedClause(
@@ -105,16 +105,16 @@ foreach ($tables as $each_table) {
} else {
$is_checked = ' checked="checked"';
}
- if (isset($_GET['table_structure']) && is_array($_GET['table_structure'])) {
+ if (isset($_POST['table_structure']) && is_array($_POST['table_structure'])) {
$structure_checked = Export::getCheckedClause(
- $each_table['Name'], $_GET['table_structure']
+ $each_table['Name'], $_POST['table_structure']
);
} else {
$structure_checked = $is_checked;
}
- if (isset($_GET['table_data']) && is_array($_GET['table_data'])) {
+ if (isset($_POST['table_data']) && is_array($_POST['table_data'])) {
$data_checked = Export::getCheckedClause(
- $each_table['Name'], $_GET['table_data']
+ $each_table['Name'], $_POST['table_data']
);
} else {
$data_checked = $is_checked;
@@ -84,19 +84,19 @@ if (!empty($_POST['selected_tbl']) && empty($table_select)) {
$table_select = $_POST['selected_tbl'];
}
-// Check if the selected tables are defined in $_GET
+// Check if the selected tables are defined in $_POST
// (from clicking Back button on export.php)
foreach (array('table_select', 'table_structure', 'table_data') as $one_key) {